@@ -32,7 +32,7 @@ import hildon
 
 # defined the default styles
 DEFAULT_STYLES = {
-    'DEFAULT':      {'font': 'monospace'},
+    'DEFAULT':      {},
     'comment':      {'foreground': '#0000FF'},
     'preprocessor': {'foreground': '#A020F0'},
     'keyword':      {'foreground': '#A52A2A',
