@@ -208,7 +208,7 @@ class Window(hildon.Window):
     if (event.state==gtk.gdk.CONTROL_MASK):
       #Save : CTRL-S
       if (event.keyval == gtk.keysyms.s):
-        self.save(self.filepath)
+        self.save()
       #Undo : CTRL-Z
       elif (event.keyval == gtk.keysyms.z):
         self.code_editor.buffer.undo()
