@@ -69,9 +69,9 @@ class PyGTKEditor:
       
   def onAbout(self, widget):
     import about
-    d = about.Dialog('PyGTKEditor',self.VERSION,'A source code editor for Maemo','pygtkeditor','GPLv2','http://khertan.net/','http://bugs.maemo.org')
-    d.run()
-    d.destroy()
+    dial = about.Dialog('PyGTKEditor',self.VERSION,'A source code editor for Maemo','pygtkeditor','GPLv2','http://khertan.net/','http://bugs.maemo.org')
+    dial.run()
+    dial.destroy()
 
   def _manage_theme(self):
     icons = (( gtk.STOCK_ADD,   "general_add" ),
@@ -116,10 +116,10 @@ class PyGTKEditor:
   
   def close_win(self,widget,*data):
     if widget.saved == False:
-      n = hildon.hildon_note_new_confirmation(hildon.Window(),'Did you want to save this unsaved file ?')
-      if n.run() == gtk.RESPONSE_OK:
+      noteconf = hildon.hildon_note_new_confirmation(hildon.Window(),'Did you want to save this unsaved file ?')
+      if noteconf.run() == gtk.RESPONSE_OK:
         widget.save()
-      n.destroy()
+      noteconf.destroy()
         
   def destroy_win(self,widget,*data):
     self.window_list.remove(widget)
@@ -127,17 +127,17 @@ class PyGTKEditor:
       gtk.main_quit()
     
   def create_window(self,filepath=None):
-    w1 = pge_window.Window(filepath,self)
-    w1.connect("destroy", self.destroy_win)
-    w1.connect("delete-event", self.close_win)
+    newwin = pge_window.Window(filepath,self)
+    newwin.connect("destroy", self.destroy_win)
+    newwin.connect("delete-event", self.close_win)
     if self.window_list==None:
       self.window_list = []
-    self.window_list.append(w1)
-    self.app.add_window(w1)
+    self.window_list.append(newwin)
+    self.app.add_window(newwin)
     
   def apply_prefs(self):
-    for w in self.window_list:
-      w.apply_prefs()
+    for window in self.window_list:
+      window.apply_prefs()
 
 if __name__ == "__main__":
   PyGTKEditor()
